@@ -151,7 +151,7 @@ class ParseMessage:
 
         oid_types = [buff.read_int32() for _ in range(parameter_data_types_len)]
 
-        print(f"Parse : name {name}, {query}, {oid_types}")
+        logging.info(f"Parse : name {name}, {query}, {oid_types}")
 
         return ParseMessage(
             name=name,
@@ -248,13 +248,13 @@ class Message:
             return None, None
 
         fn = message_type_map.get(ord(t), None)
-        print(f"Read message type {t} using fn {fn}")
+        logging.info(f"Read message type {t} using fn {fn}")
         if fn:
             try:
                 inner_buff, _ = buff.read_int32_delim_message()
                 return fn(inner_buff), t
             except Exception as e:
-                print(e)
+                logging.error(e)
                 return fn(ReadingIO(io.BytesIO())), t
 
         return None, t
