@@ -134,7 +134,12 @@ def process_parse_command(context: Context):
                 return context, Names.CLOSE
 
         else:
+            logging.error("Closing from Parse no query")
             return context, Names.CLOSE
+    except Exception as e:
+        log_exception(e)
+        logging.error(f"Error when parsing {msg}")
+        return context, Names.CLOSE
     finally:
         logging.info("######################################################")
 
